@@ -6,7 +6,7 @@
 ;;         MORIOKA Tomohiko <morioka@jaist.ac.jp>
 ;; Maintainer: MORIOKA Tomohiko <morioka@jaist.ac.jp>
 ;; Created: 1994/08/21 renamed from mime.el
-;; Version: $Revision: 7.106 $
+;; Version: $Revision: 7.108 $
 ;; Keywords: mail, news, MIME, multimedia, multilingual
 
 ;; This file is part of tm (Tools for MIME).
@@ -120,7 +120,7 @@
 ;;;
 
 (defconst mime-editor/RCS-ID
-  "$Id: tm-edit.el,v 7.106 1997/03/20 07:20:15 morioka Exp $")
+  "$Id: tm-edit.el,v 7.108 1997/05/27 03:22:55 morioka Exp $")
 
 (defconst mime-editor/version (get-version-string mime-editor/RCS-ID))
 
@@ -1554,8 +1554,9 @@ Parameter must be '(PROMPT CHOICE1 (CHOISE2 ...))."
 	    (insert (format "Content-Transfer-Encoding: %s\n" encoding))
 	  )
 	(insert "\n")
-	(or (funcall (pgp-function 'mime-sign)
-		     (point-min)(point-max) nil nil pgp-boundary)
+	(or (as-binary-process
+	     (funcall (pgp-function 'mime-sign)
+		      (point-min)(point-max) nil nil pgp-boundary))
 	    (throw 'mime-editor/error 'pgp-error)
 	    )
 	))))
